@@ -1,4 +1,5 @@
 """Py-nf core functionality."""
+import re
 import subprocess
 import os
 import sys
@@ -11,7 +12,7 @@ import warnings
 
 
 __author__ = "Bogdan Kirilenko"
-__version__ = "0.2.4"
+__version__ = "0.2.5"
 CURRENT_DIR = os.path.dirname(__file__)
 
 
@@ -24,6 +25,8 @@ MAX_RETRIES_PARAM = "max_retries"
 QUEUE_PARAM = "queue"
 MEMORY_PARAM = "memory"
 TIME_PARAM = "time"
+MEMORY_UNITS_PARAM = "memory_units"
+TIME_UNITS_PARAM = "time_units"
 CPUS_PARAM = "cpus"
 VERBOSE = "verbose"
 QUEUE_SIZE_PARAM = "queue_size"
@@ -41,6 +44,12 @@ NEXTFLOW_LOG_FILENAME = ".nextflow.log"
 DEFAULT_SCRIPT_NAME = "script.nf"
 DEFAULT_CONFIG_NAME = "config.nf"
 
+AVAILABLE_MEMORY_UNITS = {"B", "KB", "MB", "GB", "TB"}
+AVAILABLE_TIME_UNITS = {"ms", "milli", "millis",
+                        "s", "sec", "seconds",
+                        "m", "min", "minute", "minutes",
+                        "h", "hour", "hours",
+                        "d", "day", "days"}
 
 class Nextflow:
     """Nextflow wrapper."""
@@ -56,6 +65,13 @@ class Nextflow:
         "moab": "msub",
         "nqsii": "qsub",
         "condor": "condor_submit",
+        # I didn't find any known binaries to check
+        # whether they are valud upfront
+        "ignite": None,
+        "kubernetes": None,
+        "awsbatch": None,
+        "google-lifesciences": None,
+        "tes": None,
     }
 
     def __init__(self, **kwargs):
@@ -71,7 +87,9 @@ class Nextflow:
             RETRY_INCREASE_TIME_PARAM,
             QUEUE_PARAM,
             MEMORY_PARAM,
+            MEMORY_UNITS_PARAM,
             TIME_PARAM,
+            TIME_UNITS_PARAM,
             CPUS_PARAM,
             QUEUE_SIZE_PARAM,
             REMOVE_LOGS_PARAM,
@@ -106,8 +124,8 @@ class Nextflow:
         self.max_retries = kwargs.get(MAX_RETRIES_PARAM, 3)
         self.queue = kwargs.get(QUEUE_PARAM, "batch")
         # TODO: fix this, must always be {number}.{units}
-        self.memory = kwargs.get(MEMORY_PARAM, "10.GB")
-        self.time = kwargs.get(TIME_PARAM, "1.h")
+        self.memory = self.__set_memory(kwargs.get(MEMORY_PARAM, "10"), kwargs.get(MEMORY_UNITS_PARAM, "GB"))
+        self.time = self.__set_time(kwargs.get(TIME_PARAM, "1"), kwargs.get(TIME_UNITS_PARAM, "h"))
         self.cpus = kwargs.get(CPUS_PARAM, 1)
         self.queue_size = kwargs.get(QUEUE_SIZE_PARAM, 100)
         self.retry_increase_mem = kwargs.get(RETRY_INCREASE_MEMORY_PARAM, False)
@@ -137,6 +155,20 @@ class Nextflow:
             warnings.warn(msg)
         self.__v(f"Initiated py_nf with the following params:\n{self.__repr__()}")
 
+    def __set_memory(self, quantity, units):
+        """Get memory parameter as a string."""
+        if units not in AVAILABLE_MEMORY_UNITS:
+            raise ValueError(f"Invalid {MEMORY_UNITS_PARAM} parameter {units}, "
+                             f"please select one of these:\n{AVAILABLE_MEMORY_UNITS}")
+        return f"{quantity}.{units}"
+    
+    def __set_time(self, quantity, units):
+        """Get memory parameter as a string."""
+        if units not in AVAILABLE_TIME_UNITS:
+            raise ValueError(f"Invalid {TIME_UNITS_PARAM} parameter {units}, "
+                             f"please select one of these:\n{AVAILABLE_TIME_UNITS}")
+        return f"{quantity}.{units}"
+
     def __v(self, msg):
         """Verbosity message."""
         sys.stderr.write(f"{msg}\n") if self.verbosity_on else None
@@ -178,6 +210,9 @@ class Nextflow:
         # we have a supported executor, need to check whether the required
         # executable exists
         depend_exe = self.executor_to_depend[self.executor]
+        if depend_exe is None:
+            # no way to check, just return True -> let the nextflow and user to figure this out
+            return True
         depend_exists = shutil.which(depend_exe)
         if depend_exists:
             # this is fine, let's go further
@@ -445,6 +480,9 @@ def pick_executor():
     # TODO: if qsub is available then we need some extra procedure
     # please see issue #1
     for executor, dep_bin in Nextflow.executor_to_depend.items():
+        if dep_bin is None:
+            # here we cannot say for sure
+            continue
         depend_available = shutil.which(dep_bin)
         if depend_available is None:
             continue
